# ICM20948 9-DOF Accelerometer, Magnetometer and Gyroscope

[![Build Status](https://img.shields.io/github/actions/workflow/status/pimoroni/icm20948-python/test.yml?branch=main)](https://github.com/pimoroni/icm20948-python/actions/workflows/test.yml)
[![Coverage Status](https://coveralls.io/repos/github/pimoroni/icm20948-python/badge.svg?branch=main)](https://coveralls.io/github/pimoroni/icm20948-python?branch=main)
[![PyPi Package](https://img.shields.io/pypi/v/icm20948.svg)](https://pypi.python.org/pypi/icm20948)
[![Python Versions](https://img.shields.io/pypi/pyversions/icm20948.svg)](https://pypi.python.org/pypi/icm20948)


# Installing

If you've already set up a Python virtual environment, you can also install the stable library manually from PyPi:

```
pip install icm20948
```

Otherwise our install script will set one up for you.

Stable library from GitHub:

```
git clone https://github.com/pimoroni/icm20948-python
cd icm20948-python
./install.sh
```

Latest/development library from GitHub:

```
git clone https://github.com/pimoroni/icm20948-python
cd icm20948-python
./install.sh --unstable
```

**Note** Libraries will be installed in the "pimoroni" virtual environment, you will need to activate it to run examples:
